extensions [gogo]

globals [
  serial-port   ;; different on different operating systems
]

breed [apples apple]
breed [blueberries blueberry]
breed [kiwis kiwi]
breed [mangoes mango]

apples-own [ energy phFactor]
blueberries-own [ energy phFactor]
kiwis-own [ energy phFactor]
mangoes-own [ energy phFactor]

to setup
  set serial-port user-one-of "Select a port:" gogo:ports
  gogo:open serial-port
  repeat 5
  [ if not gogo:ping
    [ user-message "The GoGo Board is not responding." ] ]
  gogo:talk-to-output-ports [ "a" "b" "c" "d" ]
  set-current-plot "Sensors"
  
  clear-all
  grow-water-and-nutrients
  set-default-shape apples "circle"
  create-apples apple-seed [
    set color red
    setxy random-xcor random-ycor
    set phFactor 5.75
    ifelse (abs ((gogo:sensor 1 - 345) / -10 - phFactor) < 1) [ set energy 20] [set energy 10]
  ]
  
  set-default-shape blueberries "circle"
  create-blueberries blueberry-seed [
    set color blue
    setxy random-xcor random-ycor
    set phFactor 4.5
    ifelse (abs ((gogo:sensor 1 - 345) / -10 - phFactor) < 1) [ set energy 20] [set energy 10]
  ]
  
  set-default-shape kiwis "circle"
  create-kiwis kiwi-seed [
    set color green
    setxy random-xcor random-ycor
    set phFactor 6.75
    ifelse (abs ((gogo:sensor 1 - 345) / -10 - phFactor) < 1) [ set energy 20] [set energy 10]
  ]
    
  set-default-shape mangoes "circle"
  create-mangoes mango-seed [
    set color orange
    setxy random-xcor random-ycor
    set phFactor 6.75
    ifelse (abs ((gogo:sensor 1 - 345) / -10 - phFactor) < 1) [ set energy 20] [set energy 10]
  ]
  setup-plot
  do-plot
end

to gogo-ping
  carefully
  [ if not gogo:ping
    [ user-message "Unable to ping GoGo Board." ] ]
  [ user-message error-message ]
end

to go
  if not any? turtles [ stop ]
  grow-water-and-nutrients
  ask turtles
  [ move
    eat-water
    eat-nutrients
    reproduce
    death ]
 
  
  tick
  do-plot
end

to grow-water-and-nutrients
  ask patches [
    if pcolor = black [
      if random-float 1000 < nutrients-grow-rate
        [ set pcolor brown ]
      if random-float 1000 < water-grow-rate
        [ set pcolor cyan ]
  ] ]
end

to move  ;; move procedure
  rt random 50
  lt random 50
  fd 1
  ;; moving takes some energy
  set energy energy - 0.5
end

to eat-water  ;; water absorb procedure
  ;; gain "water-energy" by eating water
  if pcolor = cyan
  [ set pcolor black
    set energy energy + water-energy ]
end

to eat-nutrients  ;; nutrient absorb procedure
  ;; gain "nutrient-energy" by eating nutrients
  if pcolor = brown
  [ set pcolor black
    set energy energy + nutrient-energy ]
end

to reproduce     ;; growth procedure
  ;; give birth to a new fruit, but it takes lots of energy
  let factor phFactor
  
  if energy > birth-threshold
    [ set energy energy / 2
      hatch 1 [ 
        fd 1 
        ifelse (abs ((gogo:sensor 1 - 345) / -10 - phFactor) < 1) [ set energy 10 + pHadvantage] [set energy 10]
        ] ]
end

to death     ;; apple procedure
  ;; die if you run out of energy
  if energy < 0 [ die ]
end

;;; plotting procedures

to setup-plot
  set-current-plot "Populations"
  set-plot-y-range 0 100
end

to plot-sensor-value [ plot-sensor ]
 if plot-sensor != "none"
 [
   set-current-plot-pen plot-sensor
   if plot-sensor = "sensor 1"
       [ plot (gogo:sensor 1) ]
   if plot-sensor = "sensor 2"
       [ plot (gogo:sensor 2) ]
   if plot-sensor = "sensor 3"
       [ plot (gogo:sensor 3) ]
   if plot-sensor = "sensor 4"
       [ plot (gogo:sensor 4) ]
   if plot-sensor = "sensor 5"
       [ plot (gogo:sensor 5) ]
   if plot-sensor = "sensor 6"
       [ plot (gogo:sensor 6) ]
   if plot-sensor = "sensor 7"
       [ plot (gogo:sensor 7) ]
   if plot-sensor = "sensor 8"
       [ plot (gogo:sensor 8) ]
  ]
end

to do-plot
  set-current-plot "Populations"
  set-current-plot-pen "water"
  plot count patches with [pcolor = cyan] / 4
  set-current-plot-pen "nutrients"
  plot count patches with [pcolor = brown] / 4
  set-current-plot-pen "apples"
  plot count apples
  set-current-plot-pen "blueberries"
  plot count blueberries
  set-current-plot-pen "kiwis"
  plot count kiwis
  set-current-plot-pen "mangoes"
  plot count mangoes
  set-current-plot "Sensors"
  plot-sensor-value plot-sensor-1
end
@#$#@#$#@
GRAPHICS-WINDOW
296
13
798
536
20
20
12.0
1
10
1
1
1
0
1
1
1
-20
20
-20
20
1
1
1
ticks

BUTTON
209
43
264
76
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
209
94
264
127
go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

SLIDER
11
238
158
271
water-grow-rate
water-grow-rate
0.0
20.0
5
1.0
1
NIL
HORIZONTAL

SLIDER
11
271
158
304
nutrients-grow-rate
nutrients-grow-rate
0.0
20.0
5
1.0
1
NIL
HORIZONTAL

SLIDER
160
238
282
271
water-energy
water-energy
0.0
10.0
5
0.5
1
NIL
HORIZONTAL

SLIDER
160
271
282
304
nutrient-energy
nutrient-energy
0.0
10.0
5
0.5
1
NIL
HORIZONTAL

SLIDER
11
66
183
99
apple-seed
apple-seed
0.0
100.0
50
1.0
1
NIL
HORIZONTAL

SLIDER
11
204
183
237
birth-threshold
birth-threshold
0.0
20.0
10
1.0
1
NIL
HORIZONTAL

PLOT
804
14
1295
253
Populations
Time
Pop
0.0
100.0
0.0
111.0
true
true
PENS
"water" 1.0 0 -11221820 true
"apples" 1.0 0 -2674135 true
"nutrients" 1.0 0 -6459832 true
"kiwis" 1.0 0 -10899396 true
"blueberries" 1.0 0 -13345367 true
"mangoes" 1.0 0 -955883 true

MONITOR
36
322
145
367
count apples
count apples
1
1
11

MONITOR
36
470
145
515
count mangoes
count mangoes
1
1
11

MONITOR
36
421
145
466
count kiwis
count kiwis
1
1
11

MONITOR
36
372
145
417
count blueberries
count blueberries
1
1
11

SLIDER
11
100
183
133
blueberry-seed
blueberry-seed
0
100
50
1
1
NIL
HORIZONTAL

SLIDER
11
135
183
168
kiwi-seed
kiwi-seed
0
100
50
1
1
NIL
HORIZONTAL

SLIDER
11
169
183
202
mango-seed
mango-seed
0
100
50
1
1
NIL
HORIZONTAL

MONITOR
37
520
145
565
count fruits
count turtles
1
1
11

MONITOR
150
322
255
367
% of apples
count apples / count turtles * 100
1
1
11

MONITOR
150
372
255
417
% of blueberries
count blueberries / count turtles * 100
1
1
11

MONITOR
150
421
255
466
% of kiwis
count kiwis / count turtles * 100
1
1
11

MONITOR
150
470
255
515
% of mangoes
count mangoes / count turtles * 100
1
1
11

MONITOR
151
520
255
565
Total %
count turtles / count turtles * 100
17
1
11

SLIDER
11
14
183
47
pHadvantage
pHadvantage
0
1
0.5
.1
1
NIL
HORIZONTAL

CHOOSER
804
260
942
305
plot-sensor-1
plot-sensor-1
"sensor 1"
0

PLOT
806
318
1295
536
Sensors
NIL
NIL
0.0
10.0
0.0
14.0
true
true
PENS
"sensor 1" 1.0 0 -2674135 true

MONITOR
949
259
1009
304
sensor 1
(gogo:sensor 1 - 345) / -10
2
1
11

BUTTON
209
143
272
176
ping
print gogo:ping
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

@#$#@#$#@
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

rabbit
false
0
Circle -7500403 true true 76 150 148
Polygon -7500403 true true 176 164 222 113 238 56 230 0 193 38 176 91
Polygon -7500403 true true 124 164 78 113 62 56 70 0 107 38 124 91

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 4.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
